# tune

[![GitHub release](https://img.shields.io/github/release/fugue-project/tune.svg)](https://GitHub.com/fugue-project/tune)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/tune.svg)](https://pypi.python.org/pypi/tune/)
[![PyPI license](https://img.shields.io/pypi/l/tune.svg)](https://pypi.python.org/pypi/tune/)
[![PyPI version](https://badge.fury.io/py/tune.svg)](https://pypi.python.org/pypi/tune/)
[![Coverage Status](https://coveralls.io/repos/github/fugue-project/tune/badge.svg)](https://coveralls.io/github/fugue-project/tune)
[![Doc](https://readthedocs.org/projects/tune/badge)](https://tune.readthedocs.org)

[![Slack Status](https://img.shields.io/badge/slack-join_chat-white.svg?logo=slack&style=social)](https://join.slack.com/t/fugue-project/shared_invite/zt-jl0pcahu-KdlSOgi~fP50TZWmNxdWYQ)

An abstraction layer for hyperparameter tuning
